@@ -1,6 +1,6 @@
 // Copyright Contributors to the Open Shading Language project.
 // SPDX-License-Identifier: BSD-3-Clause
-// https://github.com/imageworks/OpenShadingLanguage
+// https://github.com/AcademySoftwareFoundation/OpenShadingLanguage
 
 
 // Extend Imath matrix classes to include 2x2, as analogous as possible
@@ -959,7 +959,7 @@ Matrix22<T>::inverse (bool singExc) const
                 {
 #ifndef __CUDA_ARCH__
                     if (singExc)
-                        throw Imath::SingMatrixExc ("Cannot invert "
+                        throw std::invalid_argument ("Cannot invert "
                                              "singular matrix.");
 #endif
                     return Matrix22();
